@@ -32,4 +32,9 @@ class StoredResponses:
     resp_404: Response
     raw_resp_400: Optional[RawHttpResponse]
     resp_favicon: Optional[Response]
-    long_resp: Optional[Response]
\ No newline at end of file
+    long_resp: Optional[Response]
+    http_resp: Optional[Response]
+    https_resp: Optional[Response]
+    http_invalid_method: Optional[Response]
+    http_invalid_protocol: Optional[Response]
+    http_invalid_version: Optional[Response]
\ No newline at end of file
